#!/usr/bin/env node
"use strict";
const fs = require("fs");
const path = require("path");
const yargs = require("yargs");
const helpers = require("yargs/helpers");
const awaitSpawn = require("./src/await-spawn.cjs");
async function main() {
  const args = await yargs(helpers.hideBin(process.argv)).command("$0 <name>", "Initialize an Nx-managed repository using the eternagame layout preset", (y) => y.positional("name", { type: "string", demandOption: true })).option("eterna", {
    describe: "Use defaults intended for packages manged by the Eterna project",
    boolean: true,
    default: false
  }).option("npmScope", {
    describe: "Npm scope packages should be scoped to/published under",
    type: "string"
  }).option("generator-version", {
    describe: "Specifies the version of @eternagame/nx-plugin used for repository generation (eg --generator-version canary for the latest canary)",
    type: "string"
  }).argv;
  fs.mkdirSync(args.name);
  fs.writeFileSync(path.join(args.name, "package.json"), JSON.stringify({ name: args.name }));
  await awaitSpawn("git", ["init"], { cwd: args.name });
  const pluginVersion = args.generatorVersion ?? "latest";
  await awaitSpawn("npm", ["install", `@eternagame/nx-plugin@${pluginVersion}`], { cwd: args.name });
  const options = [
    args.name,
    ...args.eterna ? ["--eternaDefaults"] : [],
    ...args.npmScope ? ["--npmScope", args.npmScope] : []
  ];
  await awaitSpawn("npx", ["nx", "g", "@eternagame/nx-plugin:preset", ...options], {
    cwd: args.name
  });
}
main().catch((e) => {
  console.error(e);
});
//# sourceMappingURL=index.cjs.map
